@@ -11,27 +11,28 @@ import time
 import datetime as dt
 import sys
 import os
+import unicodedata
 
 name = 'telegram_util'
 
 def hasSeq(text, sequences):
-    if not text:
-        return False
-    for seq in sequences:
-        index = 0
-        for char in seq:
-            index = text.find(char, index)
-            if index == -1:
-                break
-        if index != -1:
-            return True
-    return False
+	if not text:
+		return False
+	for seq in sequences:
+		index = 0
+		for char in seq:
+			index = text.find(char, index)
+			if index == -1:
+				break
+		if index != -1:
+			return True
+	return False
 
 def isprintable(s):
-    try: 
-    	s.encode('utf-8')
-    except UnicodeEncodeError: return False
-    else: return True
+	try: 
+		s.encode('utf-8')
+	except UnicodeEncodeError: return False
+	else: return True
 
 def cutCaptionHtml(text, limit):
 	text = ''.join([c for c in text if isprintable(c)])
@@ -110,8 +111,11 @@ class AlbumResult(object):
 		self.hash = ''
 		self.url = ''
 		self.cap_html_v2 = ''
+		self.no_parse = False
 
 	def getParseMode(self):
+		if self.no_parse:
+			return
 		if self.cap_html_v2:
 			return 'HTML'
 		if self.cap_html and 'weibo' not in self.url:
@@ -126,9 +130,9 @@ class AlbumResult(object):
 		new_album.imgs = self.imgs
 		new_album.video = self.video
 		if self.imgs or self.video:
-			limit = 4000 - len(self.url) - 10
-		else:
 			limit = 1000 - len(self.url) - 10
+		else:
+			limit = 4000 - len(self.url) - 10
 		if self.cap_html_v2:
 			new_album.cap_html_v2 = cutCaptionHtml(self.cap_html_v2, limit) + '\n\n' + self.url
 		elif self.cap or self.imgs or self.video:
@@ -150,6 +154,17 @@ def compactText(text):
 		text = text.replace('\n\n\n', '\n\n')
 	return text.strip()
 
+def compactTextV2(text):
+	for _ in range(10):
+		text = text.replace('  ', ' ')
+		text = text.replace('\r', '\n')
+		text = text.replace('\n ', '\n')
+		text = text.replace(' \n', '\n')
+		text = text.replace('\xa0', ' ')
+	for _ in range(20):	
+		text = text.replace('\n\n\n', '\n\n')
+	return text.strip()
+
 def escapeMarkdown(text):
 	in_bracket = False
 	r = []
@@ -189,6 +204,13 @@ def isCN(title):
 		return True
 	return False
 
+def isArab(text):
+	for c in text:
+		name = unicodedata.name(c).lower()
+		if 'arabic' in name or 'persian' in name:
+			return True
+	return False
+
 TO_CLEAN = '#/?'
 def cleanFileName(name):
 	for x in TO_CLEAN:
@@ -305,6 +327,15 @@ def autoDestroy(msg, minutes=1):
 		return
 	threading.Timer(minutes * 60, lambda: tryDelete(msg)).start() 
 
+class WaitTimer():
+	def __init__(self):
+		self.timer = {}
+
+	def wait(self, key, sec):
+		time.sleep(max(0, self.timer.get(key, 0) - time.time()))
+		self.timer[key] = time.time() + sec
+wait_timer = WaitTimer()
+
 class TimedDeleter():
 	def __init__(self):
 		self.queue = []
@@ -467,25 +498,38 @@ def getOrigins(msg):
 	return set([str(item) for item in result if item])
 
 def getTitleFromText(text):
-    text = text.strip().split('\n')[0].strip()
-    text = text.split('。')[0]
-    if text.startswith('【'):
-        new_text = text.split('】')[0][1:]
-        if len(new_text) > 5:
-            text = new_text
-    text = text.strip()
-    if text.endswith('source'):
-        text = text[:-6].strip()
-    if not text.startswith('【网评】'):
-        text = text.split('【网评】')[0]
-    if text.endswith('】') and text.startswith('【'):
-        text = text[1:-1]
-    if text.startswith('【'):
-        index = text.rfind('】')
-        if index != -1:
-            text = text[1 :index + 1] + '【' + text[index + 1:]
-    if text.endswith('】'):
-        index = text.find('【')
-        if index != -1:
-            text = text[:index] + '】' + text[index:-1] 
-    return text.replace('#', '')
\ No newline at end of file
+	text = text.strip().split('\n')[0].strip()
+	text = text.split('。')[0]
+	if text.startswith('【'):
+		new_text = text.split('】')[0][1:]
+		if len(new_text) > 5:
+			text = new_text
+	text = text.strip()
+	if text.endswith('source'):
+		text = text[:-6].strip()
+	if not text.startswith('【网评】'):
+		text = text.split('【网评】')[0]
+	if text.endswith('】') and text.startswith('【'):
+		text = text[1:-1]
+	if text.startswith('【'):
+		index = text.rfind('】')
+		if index != -1:
+			text = text[1 :index + 1] + '【' + text[index + 1:]
+	if text.endswith('】'):
+		index = text.find('【')
+		if index != -1:
+			text = text[:index] + '】' + text[index:-1] 
+	return text.replace('#', '')
+
+def send_message(chat, message, parse_mode='Markdown'):
+    try:
+        chat.send_message(message, disable_web_page_preview=True, parse_mode='markdown')
+    except Exception as e:
+        if 'Timed out' in str(e):
+            return
+        if str(e).endswith('seconds'):
+        	wait = int(str(e).split()[-2])
+        	time.sleep(wait + 5)
+        	send_message(chat, message, parse_mode=parse_mode)
+        	return
+        chat.send_message(message, disable_web_page_preview=True)
\ No newline at end of file
